/**
 * @file   httpget.cpp
 * @author NOKUBI Takatsugu
 * @date   Fri Dec 26 15:03:58 2003
 * 
 * @brief  http get class
 * 
 * $Id$
 */

#include "httpget.h"
#include "qhttp.h"
#include <qurloperator.h>
#include <qnetwork.h>
#include <qurl.h>

HttpGet::HttpGet(const QString &u)
{
  url = new QUrl(u);
  http = new QHttp();
  int port = url->port();
  if (port < 0) port = 80;
  http->setHost(url->host(), port);
  qDebug("host: %s, port %d", (const char *)url->host(), port);
  cont.truncate(0);
  stat = Null;
}

HttpGet::~HttpGet()
{
  delete url;
  delete http;
  cont.truncate(0);
}

void HttpGet::get()
{
  qDebug("get");
  connect(http, SIGNAL(done(bool)),
	  this, SLOT(recvdone(bool)));
  http->get(url->path(), &buf);
  qDebug("path: %s", (const char *)url->path());
  stat = InProgress;
  emit getstart();
}

HttpGet::Status HttpGet::status()
{
  return stat;
}

QString& HttpGet::contents()
{
  return cont;
}

void HttpGet::recvdone(bool s)
{
    qDebug("finished: %d", s);
  stat = Finished;
  if (!s) {
      cont = QString::fromUtf8(buf.buffer());
  } else {
      qDebug("false: %s", (const char *)http->errorString());
  }
  emit getfinished();
}
